@@ -78,25 +78,31 @@ def _save(path):
     '''
     pull log from device to report folder
     '''
-    serial = os.environ['ANDROID_SERIAL'] if os.environ.has_key('ANDROID_SERIAL') else None
-    #snapshot & system log
-    bridge = _findExetuable('adb')
-    if serial:
-        AdbCommand('%s -s %s shell screencap /sdcard/%s' % (bridge ,serial, FAILURE_SNAPSHOT_NAME)).run()
-        AdbCommand('%s -s %s pull /sdcard/%s %s' % (bridge, serial, FAILURE_SNAPSHOT_NAME, path)).run()
-        output = AdbCommand('%s -s %s logcat -v time -d' % (bridge, serial)).run()
-        with open(join(path, LOG_FILE_NAME), 'w') as o:
-            o.write(output)
-    else:
-        AdbCommand('%s shell screencap /sdcard/%s' % (bridge, FAILURE_SNAPSHOT_NAME)).run()
-        AdbCommand('%s pull /sdcard/%s %s' % (bridge, FAILURE_SNAPSHOT_NAME, path)).run()
-        output = AdbCommand('%s logcat -v time -d ' % bridge).run()
-        with open(join(path, LOG_FILE_NAME), 'w') as o:
-            o.write(output)
+    try:
+        serial = os.environ['ANDROID_SERIAL'] if os.environ.has_key('ANDROID_SERIAL') else None
+        #snapshot & system log
+        bridge = _findExetuable('adb')
+        if serial:
+            AdbCommand('%s -s %s shell screencap /sdcard/%s' % (bridge ,serial, FAILURE_SNAPSHOT_NAME)).run()
+            AdbCommand('%s -s %s pull /sdcard/%s %s' % (bridge, serial, FAILURE_SNAPSHOT_NAME, path)).run()
+            output = AdbCommand('%s -s %s logcat -v time -d' % (bridge, serial)).run()
+            with open(join(path, LOG_FILE_NAME), 'w') as o:
+                o.write(output)
+        else:
+            AdbCommand('%s shell screencap /sdcard/%s' % (bridge, FAILURE_SNAPSHOT_NAME)).run()
+            AdbCommand('%s pull /sdcard/%s %s' % (bridge, FAILURE_SNAPSHOT_NAME, path)).run()
+            output = AdbCommand('%s logcat -v time -d ' % bridge).run()
+            with open(join(path, LOG_FILE_NAME), 'w') as o:
+                o.write(output)
+    except:
+        pass
 
 def _writeResultToFile(output, content):
-    with open(output, 'a') as f:
-        f.write('%s%s' % (json.dumps(content), os.linesep))
+    try:
+        with open(output, 'a') as f:
+            f.write('%s%s' % (json.dumps(content), os.linesep))
+    except:
+        pass
 
 def _calcScore(frame):
     """Calculates a score for this stack frame, so that can be used as a
@@ -333,9 +339,15 @@ class FileOutputPlugin(nose.plugins.Plugin):
             name, ext = os.path.splitext(snapshot_name)
             dest = os.path.dirname(current)
             expect_snapshot_name = '%s%s%s' % (name, '_expect', ext)
-            shutil.copyfile(expect, join(dest, expect_snapshot_name))
+            try:
+                shutil.copyfile(expect, join(dest, expect_snapshot_name))
+            except:
+                pass
             _save(dest)
-            shutil.move(dest, self._fail_report_path)
+            try:
+                shutil.move(dest, self._fail_report_path)
+            except:
+                pass
             #"screenshot_at_failure"
             screenshot_at_failure = join(case_report_dir_path, snapshot_name)
             log = join(case_report_dir_path, LOG_FILE_NAME)
@@ -347,7 +359,10 @@ class FileOutputPlugin(nose.plugins.Plugin):
             case_report_dir = _mkdir(join(tmp, case_report_dir_name))
             #last step snapshot
             _save(case_report_dir)
-            shutil.move(case_report_dir, self._fail_report_path)
+            try:
+                shutil.move(case_report_dir, self._fail_report_path)
+            except:
+                pass
 
             screenshot_at_failure = join(case_report_dir_path, FAILURE_SNAPSHOT_NAME)
             log = join(case_report_dir_path, LOG_FILE_NAME)
@@ -383,9 +398,15 @@ class FileOutputPlugin(nose.plugins.Plugin):
             name, ext = os.path.splitext(snapshot_name)
             dest = os.path.dirname(current)
             expect_snapshot_name = '%s%s%s' % (name, '_expect', ext)
-            shutil.copyfile(expect, join(dest, expect_snapshot_name))
+            try:
+                shutil.copyfile(expect, join(dest, expect_snapshot_name))
+            except:
+                pass
             _save(dest)
-            shutil.move(dest, self._error_report_path)
+            try:
+                shutil.move(dest, self._error_report_path)
+            except:
+                pass
             #"screenshot_at_failure"
             screenshot_at_failure = join(case_report_dir_path, snapshot_name)
             log = join(case_report_dir_path, LOG_FILE_NAME)
@@ -397,8 +418,10 @@ class FileOutputPlugin(nose.plugins.Plugin):
             case_report_dir = _mkdir(join(tmp, case_report_dir_name))
             #last step snapshot
             _save(case_report_dir)
-            shutil.move(case_report_dir, self._error_report_path)
-
+            try:
+                shutil.move(case_report_dir, self._error_report_path)
+            except:
+                pass
             screenshot_at_failure = join(case_report_dir_path, FAILURE_SNAPSHOT_NAME)
             log = join(case_report_dir_path, LOG_FILE_NAME)
             expect = None
